# epa-regions-python

[EPA regions](https://www.epa.gov/aboutepa/regional-and-geographic-offices) with regionmask / GeoPandas

[![Version on PyPI](https://img.shields.io/pypi/v/epa-regions.svg)](https://pypi.org/project/epa-regions/)
